==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderWebhookBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderWebhookBuilder extends ACMEIssuerDNS01ProviderWebhookFluentImpl<ACMEIssuerDNS01ProviderWebhookBuilder> implements VisitableBuilder<ACMEIssuerDNS01ProviderWebhook,ACMEIssuerDNS01ProviderWebhookBuilder>{
  public ACMEIssuerDNS01ProviderWebhookBuilder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderWebhook(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhookFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhookFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderWebhook(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhookFluent<?> fluent,ACMEIssuerDNS01ProviderWebhook instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhookFluent<?> fluent,ACMEIssuerDNS01ProviderWebhook instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConfig(instance.getConfig());
      fluent.withGroupName(instance.getGroupName());
      fluent.withSolverName(instance.getSolverName());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhook instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhook instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConfig(instance.getConfig());
      this.withGroupName(instance.getGroupName());
      this.withSolverName(instance.getSolverName());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderWebhookFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderWebhook build() {
    ACMEIssuerDNS01ProviderWebhook buildable = new ACMEIssuerDNS01ProviderWebhook(fluent.getConfig(),fluent.getGroupName(),fluent.getSolverName());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderWebhookBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderWebhookBuilder extends ACMEIssuerDNS01ProviderWebhookFluent<ACMEIssuerDNS01ProviderWebhookBuilder> implements VisitableBuilder<ACMEIssuerDNS01ProviderWebhook,ACMEIssuerDNS01ProviderWebhookBuilder>{
  public ACMEIssuerDNS01ProviderWebhookBuilder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderWebhook(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhookFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhookFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderWebhook(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhookFluent<?> fluent,ACMEIssuerDNS01ProviderWebhook instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhookFluent<?> fluent,ACMEIssuerDNS01ProviderWebhook instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderWebhook());

    if (instance != null) {
      fluent.withConfig(instance.getConfig());
      fluent.withGroupName(instance.getGroupName());
      fluent.withSolverName(instance.getSolverName());
      fluent.withConfig(instance.getConfig());
      fluent.withGroupName(instance.getGroupName());
      fluent.withSolverName(instance.getSolverName());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhook instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderWebhookBuilder(ACMEIssuerDNS01ProviderWebhook instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderWebhook());

    if (instance != null) {
      this.withConfig(instance.getConfig());
      this.withGroupName(instance.getGroupName());
      this.withSolverName(instance.getSolverName());
      this.withConfig(instance.getConfig());
      this.withGroupName(instance.getGroupName());
      this.withSolverName(instance.getSolverName());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderWebhookFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderWebhook build() {
    ACMEIssuerDNS01ProviderWebhook buildable = new ACMEIssuerDNS01ProviderWebhook(fluent.getConfig(),fluent.getGroupName(),fluent.getSolverName());
    return buildable;
  }
  
}
